@@ -2,8 +2,6 @@
 /**
  * This file contains the Net_Sieve class.
  *
- * PHP version 5
- *
  * +-----------------------------------------------------------------------+
  * | All rights reserved.                                                  |
  * |                                                                       |
@@ -38,8 +36,8 @@
  * @author    Jan Schneider <jan@horde.org>
  * @copyright 2002-2003 Richard Heyes
  * @copyright 2006-2008 Anish Mistry
- * @license   http://www.opensource.org/licenses/bsd-license.php BSD
- * @link      http://pear.php.net/package/Net_Sieve
+ * @license   https://www.opensource.org/licenses/bsd-license.php BSD
+ * @link      https://pear.php.net/package/Net_Sieve
  */
 
 require_once 'PEAR.php';
@@ -80,7 +78,7 @@ define('NET_SIEVE_STATE_TRANSACTION', 3);
  * @copyright 2002-2003 Richard Heyes
  * @copyright 2006-2008 Anish Mistry
  * @license   http://www.opensource.org/licenses/bsd-license.php BSD
- * @version   Release: 1.4.5
+ * @version   Release: 1.4.6
  * @link      http://pear.php.net/package/Net_Sieve
  * @link      http://tools.ietf.org/html/rfc5228 RFC 5228 (Sieve: An Email
  *            Filtering Language)
@@ -127,6 +125,13 @@ class Net_Sieve
      */
     var $_data;
 
+    /**
+     * Server capabilities.
+     *
+     * @var array
+     */
+    var $_capability = array();
+
     /**
      * Current state of the connection.
      *
@@ -268,7 +273,7 @@ class Net_Sieve
             );
         }
 
-        if (strlen($user) && strlen($pass)) {
+        if (is_string($user) && strlen($user) && strlen($pass)) {
             $this->_error = $this->_handleConnectAndLogin();
         }
     }
@@ -757,15 +762,15 @@ class Net_Sieve
             return $this->_pear->raiseError('No Kerberos service principal set', 2);
         }
 
-        if (!$this->_gssapiCN) {
-            return $this->_pear->raiseError('No Kerberos service CName set', 2);
+        if (!empty($this->_gssapiCN)) {
+            putenv('KRB5CCNAME=' . $this->_gssapiCN);
         }
 
-        putenv('KRB5CCNAME=' . $this->_gssapiCN);
-
         try {
             $ccache = new KRB5CCache();
-            $ccache->open($this->_gssapiCN);
+            if (!empty($this->_gssapiCN)) {
+                $ccache->open($this->_gssapiCN);
+            }
 
             $gssapicontext = new GSSAPIContext();
             $gssapicontext->acquireCredentials($ccache);
@@ -1125,8 +1130,7 @@ class Net_Sieve
     function _parseCapability($data)
     {
         // Clear the cached capabilities.
-        $this->_capability = array('sasl' => array(),
-                                   'extensions' => array());
+        $this->_capability = array('sasl' => array(), 'extensions' => array());
 
         $data = preg_split('/\r?\n/', $this->_toUpper($data), -1, PREG_SPLIT_NO_EMPTY);
 
@@ -1412,7 +1416,8 @@ class Net_Sieve
         // Unfortunately old Cyrus versions are broken and don't send a
         // CAPABILITY response, thus we would wait here forever. Parse the
         // Cyrus version and work around this broken behavior.
-        if (!preg_match('/^CYRUS TIMSIEVED V([0-9.]+)/', $this->_capability['implementation'], $matches)
+        if (empty($this->_capability['implementation'])
+            || !preg_match('/^CYRUS TIMSIEVED V([0-9.]+)/', $this->_capability['implementation'], $matches)
             || version_compare($matches[1], '2.3.10', '>=')
         ) {
             $res = $this->_doCmd();
